.center[data-v-4830d223]{text-align:center}.button-row.center[data-v-4830d223]{display:flex;justify-content:center}.section-body[data-v-4830d223]{gap:1.25rem}.name-edit span[data-v-4830d223]{color:var(--color-text-muted);font-size:.9rem}
