import{o as d,x as u,b as s,y as m,k as o,a8 as l,J as h,K as p}from"./_plugin-vue_export-helper-Dvd-Cb1u.js";import{R as f}from"./RestrictedAuth-DIn6rx4R.js";import{g as a}from"./helpers-DzjFIx78.js";import"./pow-DUr-T9XX.js";const k={__name:"RestrictedForward",setup(w){const n=o(()=>l()),r=o(()=>{const e=document.documentElement.getAttribute("data-mode");return e==="reauth"?"reauth":e==="forbidden"?"forbidden":"login"});function i(){location.reload()}function c(){const t=n.value||"/auth/";window.location.pathname!==t&&history.replaceState(null,"",t),window.location.href=t}return d(()=>{window.addEventListener("keydown",t=>{t.key==="Escape"&&a()})}),(t,e)=>(s(),u(f,{mode:r.value,onAuthenticated:i,onBack:m(a),onHome:c},null,8,["mode","onBack"]))}};h(k).mount("#app");p();
